"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deepFreeze = void 0;
function deepFreeze(target) {
    switch (typeof target) {
        case 'object':
            if (Array.isArray(target)) {
                return Object.freeze(target.map(deepFreeze));
            }
            if (target instanceof Map) {
                return Object.freeze(new Map([...target.entries()].map(([k, v]) => [deepFreeze(k), deepFreeze(v)])));
            }
            if (target === null) {
                return null;
            }
            if (target instanceof Set) {
                return Object.freeze(new Set([...target.values()].map(deepFreeze)));
            }
            return Object.freeze(Object.assign({}, Object.entries(target).reduce((result, [prop, val]) => {
                result[prop] = deepFreeze(val);
                return result;
            }, {})));
        default:
            return target;
    }
}
exports.deepFreeze = deepFreeze;
//# sourceMappingURL=immutable.js.map